@@ -35,7 +35,7 @@ def exes_location():
     else:
         pymol_exe = r'C:/PyMOL/PyMOLWin.exe'
         clustalw_exe = r'C:/Program Files (x86)/ClustalW2/clustalw2.exe'
-        text_exe = r'C/Windows/system32/notepad.exe'
+        text_exe = r'C:/Windows/system32/notepad.exe'
         csv_exe = r'C:/Program Files/Microsoft Office/root/Office16/EXCEL.EXE'
 
     return pymol_exe, clustalw_exe, text_exe, csv_exe
@@ -124,25 +124,25 @@ def main():
                         folder_answer = "NO"
                         folder_name = values_m1[3]
                     elif values_m1[0] is False and values_m1[2] is False:
-                        checks.append("Missing information: create a folder or indicate its location!")
+                        checks.append("Error: create a folder or indicate its location!")
                     else:
-                        checks.append("Missing information: create a folder or indicate its location, but not both!")
+                        checks.append("Error: create a folder or indicate its location, but not both!")
                     if len(values_m1[4]) > 1:
                         prot_sequence = values_m1[4]
                     else:
-                        checks.append("Missing information: enter your protein sequence!")
+                        checks.append("Error: enter your protein sequence!")
                     if values_m1[5] is True:
                         blast_response = "LOCAL"
                     elif values_m1[6] is True:
                         blast_response == "WEB"
                     else:
-                        checks.append("Missing information: select how you want to run BLAST!")
+                        checks.append("Error: select how you want to run BLAST!")
                     if values_m1[7] is True:
                         output_programs = "YES"
                     elif values_m1[8] is True:
                         output_programs = "NO"
                     else:
-                        checks.append("Select if you want your results to be shown directly or not.")
+                        checks.append("Error: Select if you want your results to be shown directly or not.")
                 if len(checks) == 0:
                     print('Module running, be patient. This can take a couple of minutes...\n')
                     redirect_stdout(window_m1['-output-'])
@@ -154,11 +154,11 @@ def main():
                                 subprocess.Popen([settings['Pymol_location'],
                                                   workdir + '/' + folder_name + '/Blast&Modeller/query_monomer.pdb',
                                                   workdir + '/' + folder_name + '/Blast&Modeller/query_multimeric.pdb',
-                                                  currentdir + '/' + folder_name + '/Blast&Modeller/template.pdb'])
+                                                  workdir + '/' + folder_name + '/Blast&Modeller/template.pdb'])
                             elif not os.path.isfile(workdir + '/' + folder_name + '/Blast&Modeller/query_multimeric.pdb'):
                                 subprocess.Popen([settings['Pymol_location'], workdir +
                                                   '/' + folder_name + '/Blast&Modeller/query_monomer.pdb',
-                                                      workdir + '/' + folder_name + '/Blast&Modeller/template.pdb'])
+                                                  workdir + '/' + folder_name + '/Blast&Modeller/template.pdb'])
                             else:
                                 print("It seems CapiPy cannot find the template pdb file!")
                         os.chdir(workdir)
@@ -196,22 +196,22 @@ def main():
                     if values_m1_1[0] != '':
                         folder_name = values_m1_1[0]
                     else:
-                        checks.append("Missing information: indicate the folder location!")
+                        checks.append("Error: indicate the folder location!")
 
                     if values_m1_1[1] != '':
                         monomeric_model = values_m1_1[1]
                     else:
-                        checks.append("Missing information: indicate the monomeric pdb!")
+                        checks.append("Error: indicate the monomeric pdb!")
                     if values_m1_1[2] != '':
                         multimeric_model = values_m1_1[2]
                     else:
-                        checks.append("Missing information: indicate the template as a PDB code (four letter code)")
+                        checks.append("Error: indicate the template as a PDB code (four letter code)")
                     if values_m1_1[3] is True:
                         output_programs = "YES"
                     elif values_m1_1[4] is True:
                         output_programs = "NO"
                     else:
-                        checks.append("Select if you want your results to be shown directly or not.")
+                        checks.append("Error: Select if you want your results to be shown directly or not.")
                     if len(checks) == 0:
                         print('Module running, be patient. This can take a couple of minutes...\n')
                         redirect_stdout(window_m1_1['-output-'])
@@ -271,12 +271,15 @@ def main():
                     checks = []
                     if values_m2[0] is True and values_m2[2] is False:
                         folder_answer = "NO"
-                        folder_name = values_m2[1]
-                        prot_sequence = ''
-                        model_prot = ''
+                        if values_m2[1] != '':
+                            folder_name = values_m2[1]
+                            prot_sequence = ''
+                            model_prot = ''
+                        else:
+                            checks.append("Error: Please, enter the folder name or location!")
                     elif values_m2[0] is False and values_m2[2] is True:
                         folder_answer = "YES"
-                        folder_name = values_m2[3]
+                        folder_name = values_m2[3].replace('\n', '')
                         if len(values_m2[4]) > 0:
                             prot_sequence = values_m2[4].replace('\n', '')
                         if len(values_m2[5]) == 4:
@@ -287,24 +290,24 @@ def main():
                             else:
                                 model_prot = values_m2[5]
                         else:
-                            checks.append('Missing information: Enter the protein sequence or select the query '
+                            checks.append('Error: Enter the protein sequence or select the query '
                                           'from a previously created folder!')
                     elif values_m2[0] == values_m2[2]:
-                        checks.append("Missing information: create a folder or indicate its location!")
+                        checks.append("Error: create a folder or indicate its location!")
 
-                    if values_m2[5] is True:
+                    if values_m2[6] is True:
                         use_uniprot = 'YES'
-                    elif values_m2[6] is True:
+                    elif values_m2[7] is True:
                         use_uniprot = 'NO'
                     else:
-                        checks.append("Select if you want to use UniProt preferentially or not.")
+                        checks.append("Error: Select if you want to use UniProt preferentially or not.")
 
-                    if values_m2[7] is True:
+                    if values_m2[8] is True:
                         output_programs = "YES"
-                    elif values_m2[8] is True:
+                    elif values_m2[9] is True:
                         output_programs = "NO"
                     else:
-                        checks.append("Select if you want your results to be shown directly or not.")
+                        checks.append("Error: Select if you want your results to be shown directly or not.")
 
                     if len(checks) == 0:
                         print('Module running, be patient. This can take a couple of minutes...\n')
@@ -316,11 +319,11 @@ def main():
                             if output_programs == 'YES':
                                 webbrowser.open('https://www.uniprot.org/uniprot/' + str(uniprotID))
                                 time.sleep(3)
-                                subprocess.Popen([settings['text_exe'], workdir + '/' +
-                                              folder_name + '/ActiveSite/' + 'Active_site.txt'])
+                                subprocess.Popen([settings['text_exe'],
+                                                  workdir + '/' + folder_name + '/ActiveSite/Active_site.txt'])
                                 time.sleep(3)
-                                subprocess.Popen([settings['text_exe'], workdir + '/' +
-                                              folder_name + '/ActiveSite/' + 'refsequp.aln'])
+                                subprocess.Popen([settings['text_exe'],
+                                                  workdir + '/' + folder_name + '/ActiveSite/refsequp.aln'])
                             os.chdir(workdir)
                         except BaseException as error:
                             print('Something went wrong...\n' + str(error))
@@ -389,7 +392,7 @@ def main():
                     elif values_m3[8] is True:
                         output_programs = "NO"
                     else:
-                        checks.append("Select if you want your results to be shown directly or not.")
+                        checks.append("Error: Select if you want your results to be shown directly or not.")
 
                     if len(checks) == 0:
                         print('Module running, be patient. This can take a few minutes...\n')
@@ -451,11 +454,11 @@ def main():
                         residues = values_m3_1[1].replace(" ", "").split(",")
                         for res in residues:
                             if res.isdigit() is True:
-                                checks.append("\nPlease, indicate the chain also!")
+                                checks.append("\nError: Please, indicate the chain also!")
                             elif res.isalpha() is True:
-                                checks.append("There should be at least one number in there.")
+                                checks.append("Error: There should be at least one number your residues.")
                             elif res == "" or res == " ":
-                                checks.append("\nPlease, enter at least one position.")
+                                checks.append("\nError: Please, enter at least one position.")
                     elif len(values_m3_1[1]) > 0:
                         checks.append('Error: Enter at least one residue identified with it\'s number and chain (Ex. 1_A)')
                 
@@ -469,7 +472,7 @@ def main():
                     elif values_m3_1[4] is True:
                         output_programs = "NO"
                     else:
-                        checks.append("Select if you want your results to be shown directly or not.")
+                        checks.append("Error: Select if you want your results to be shown directly or not.")
 
                     if len(checks) == 0:
                         print('Module running, be patient. This can take a few minutes...\n')
@@ -544,7 +547,7 @@ def main():
                     elif values_m4[4] is True:
                         output_programs = "NO"
                     else:
-                        checks.append("Select if you want your results to be shown directly or not.")
+                        checks.append("Error: Select if you want your results to be shown directly or not.")
 
                     if len(checks) == 0:
                         print('Module running, be patient. This can take a few minutes...\n')
@@ -601,7 +604,7 @@ def main():
                         try:
                             settings[key] = values_set[key_win[key]]
                         except Exception as e:
-                            print(f'Problem updating settings from window values. Key = {key}' + str(e))
+                            print(f'Error: Problem updating settings from window values. Key = {key}' + str(e))
                         with open(settings_file, 'w') as f:
                             json.dump(settings, f)
                     sg.popup('Settings saved')
